@@ -2,7 +2,12 @@ use std::io;
 use std::io::{Read, Write};
 use termion::raw::IntoRawMode;
 
-pub fn getchar() -> Result<u8, String> {
+pub enum Error{
+    Exit,
+    Unknown,
+}
+
+pub fn getchar() -> Result<u8, Error> {
     let mut buffer = [0];
     let stdout = io::stdout().into_raw_mode().unwrap();
     let mut stdin = io::stdin();
@@ -11,11 +16,11 @@ pub fn getchar() -> Result<u8, String> {
 
     if stdin.read_exact(&mut buffer).is_ok() {
         if buffer[0] == 3 {
-            Err(String::from("got Ctrl-C, Exiting!"))
+            Err(Error::Exit)
         } else {
             Ok(buffer[0])
         }
     } else {
-        Err(String::from("not enough input given"))
+        Err(Error::Unknown)
     }
 }
